---
layout: page
title: mlx5dv_devx_obj_create / destroy / modify /query / general
section: 3
tagline: Verbs
---

# NAME

mlx5dv_devx_obj_create -   Creates a devx object

mlx5dv_devx_obj_destroy -  Destroys a devx object

mlx5dv_devx_obj_modify -   Modifies a devx object

mlx5dv_devx_obj_query -    Queries a devx object

mlx5dv_devx_general_cmd  - Issues a general command over the devx interface

# SYNOPSIS

```c
#include <infiniband/mlx5dv.h>

struct mlx5dv_devx_obj *
mlx5dv_devx_obj_create(struct ibv_context *context, const void *in, size_t inlen,
		       void *out, size_t outlen);
int mlx5dv_devx_obj_query(struct mlx5dv_devx_obj *obj, const void *in, size_t inlen,
			  void *out, size_t outlen);
int mlx5dv_devx_obj_modify(struct mlx5dv_devx_obj *obj, const void *in, size_t inlen,
			   void *out, size_t outlen);
int mlx5dv_devx_obj_destroy(struct mlx5dv_devx_obj *obj);
int mlx5dv_devx_general_cmd(struct ibv_context *context, const void *in, size_t inlen,
			    void *out, size_t outlen);
```

# DESCRIPTION

Create / destroy / modify / query a devx object, issue a general command over the devx interface.

# ARGUMENTS

*context*
:	RDMA device context to create the action on.

*in*
:	A buffer which contains the command's input data provided in a device specification format.

*inlen*
:	The size of *in* buffer in bytes.

*out*
:	 A buffer which contains the command's output data according to the device specification format.

*outlen*
:	The size of *out* buffer in bytes.

*obj*
:	For query, modify, destroy: the devx object to work on.

# RETURN VALUE

Upon success *mlx5dv_devx_create_obj* will return a new *struct
mlx5dv_devx_obj* on error NULL will be returned and errno will be set.

Upon success query, modify, destroy, general commands, 0 is returned or the value of errno on a failure.

# SEE ALSO

**mlx5dv_open_device**

AUTHOR

Yishai Hadas  <yishaih@mellanox.com>
